Class: ConstantContactClient::ContactDto1
- Inherits:
-
Object
- Object
- ConstantContactClient::ContactDto1
- Defined in:
- lib/constant_contact_client/models/contact_dto1.rb
Overview
The contact information associated with the event.
Instance Attribute Summary collapse
-
#create_time ⇒ Object
The create time of the event.
-
#email_address ⇒ Object
The email address to use to when replying to email, as well as the email that receives SO notifications.
-
#from_email_address ⇒ Object
The email address to use for sending confirmation emails.
-
#last_update_time ⇒ Object
The time the event was last modified.
-
#name ⇒ Object
The contact name to associate with the event.
-
#organization_name ⇒ Object
The organization name to associate with the event.
-
#phone_number ⇒ Object
The phone number to associate with the event.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ContactDto1
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ContactDto1
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/constant_contact_client/models/contact_dto1.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ConstantContactClient::ContactDto1` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ConstantContactClient::ContactDto1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'create_time') self.create_time = attributes[:'create_time'] end if attributes.key?(:'email_address') self.email_address = attributes[:'email_address'] end if attributes.key?(:'from_email_address') self.from_email_address = attributes[:'from_email_address'] end if attributes.key?(:'last_update_time') self.last_update_time = attributes[:'last_update_time'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'organization_name') self.organization_name = attributes[:'organization_name'] else self.organization_name = nil end if attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] end end |
Instance Attribute Details
#create_time ⇒ Object
The create time of the event.
20 21 22 |
# File 'lib/constant_contact_client/models/contact_dto1.rb', line 20 def create_time @create_time end |
#email_address ⇒ Object
The email address to use to when replying to email, as well as the email that receives SO notifications.
23 24 25 |
# File 'lib/constant_contact_client/models/contact_dto1.rb', line 23 def email_address @email_address end |
#from_email_address ⇒ Object
The email address to use for sending confirmation emails.
26 27 28 |
# File 'lib/constant_contact_client/models/contact_dto1.rb', line 26 def from_email_address @from_email_address end |
#last_update_time ⇒ Object
The time the event was last modified. ISO format
29 30 31 |
# File 'lib/constant_contact_client/models/contact_dto1.rb', line 29 def last_update_time @last_update_time end |
#name ⇒ Object
The contact name to associate with the event.
32 33 34 |
# File 'lib/constant_contact_client/models/contact_dto1.rb', line 32 def name @name end |
#organization_name ⇒ Object
The organization name to associate with the event.
35 36 37 |
# File 'lib/constant_contact_client/models/contact_dto1.rb', line 35 def organization_name @organization_name end |
#phone_number ⇒ Object
The phone number to associate with the event.
38 39 40 |
# File 'lib/constant_contact_client/models/contact_dto1.rb', line 38 def phone_number @phone_number end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/constant_contact_client/models/contact_dto1.rb', line 343 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = ConstantContactClient.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/constant_contact_client/models/contact_dto1.rb', line 54 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/constant_contact_client/models/contact_dto1.rb', line 41 def self.attribute_map { :'create_time' => :'create_time', :'email_address' => :'email_address', :'from_email_address' => :'from_email_address', :'last_update_time' => :'last_update_time', :'name' => :'name', :'organization_name' => :'organization_name', :'phone_number' => :'phone_number' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/constant_contact_client/models/contact_dto1.rb', line 319 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/constant_contact_client/models/contact_dto1.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/constant_contact_client/models/contact_dto1.rb', line 59 def self.openapi_types { :'create_time' => :'String', :'email_address' => :'String', :'from_email_address' => :'String', :'last_update_time' => :'String', :'name' => :'String', :'organization_name' => :'String', :'phone_number' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/constant_contact_client/models/contact_dto1.rb', line 292 def ==(o) return true if self.equal?(o) self.class == o.class && create_time == o.create_time && email_address == o.email_address && from_email_address == o.from_email_address && last_update_time == o.last_update_time && name == o.name && organization_name == o.organization_name && phone_number == o.phone_number end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
414 415 416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/constant_contact_client/models/contact_dto1.rb', line 414 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
306 307 308 |
# File 'lib/constant_contact_client/models/contact_dto1.rb', line 306 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
312 313 314 |
# File 'lib/constant_contact_client/models/contact_dto1.rb', line 312 def hash [create_time, email_address, from_email_address, last_update_time, name, organization_name, phone_number].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/constant_contact_client/models/contact_dto1.rb', line 127 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@email_address.nil? && @email_address.to_s.length > 128 invalid_properties.push('invalid value for "email_address", the character length must be smaller than or equal to 128.') end if !@email_address.nil? && @email_address.to_s.length < 0 invalid_properties.push('invalid value for "email_address", the character length must be great than or equal to 0.') end if !@from_email_address.nil? && @from_email_address.to_s.length > 128 invalid_properties.push('invalid value for "from_email_address", the character length must be smaller than or equal to 128.') end if !@from_email_address.nil? && @from_email_address.to_s.length < 0 invalid_properties.push('invalid value for "from_email_address", the character length must be great than or equal to 0.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 100 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.') end if @name.to_s.length < 0 invalid_properties.push('invalid value for "name", the character length must be great than or equal to 0.') end if @organization_name.nil? invalid_properties.push('invalid value for "organization_name", organization_name cannot be nil.') end if @organization_name.to_s.length > 255 invalid_properties.push('invalid value for "organization_name", the character length must be smaller than or equal to 255.') end if @organization_name.to_s.length < 0 invalid_properties.push('invalid value for "organization_name", the character length must be great than or equal to 0.') end if !@phone_number.nil? && @phone_number.to_s.length > 25 invalid_properties.push('invalid value for "phone_number", the character length must be smaller than or equal to 25.') end if !@phone_number.nil? && @phone_number.to_s.length < 1 invalid_properties.push('invalid value for "phone_number", the character length must be great than or equal to 1.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
390 391 392 |
# File 'lib/constant_contact_client/models/contact_dto1.rb', line 390 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/constant_contact_client/models/contact_dto1.rb', line 396 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
384 385 386 |
# File 'lib/constant_contact_client/models/contact_dto1.rb', line 384 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/constant_contact_client/models/contact_dto1.rb', line 183 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@email_address.nil? && @email_address.to_s.length > 128 return false if !@email_address.nil? && @email_address.to_s.length < 0 return false if !@from_email_address.nil? && @from_email_address.to_s.length > 128 return false if !@from_email_address.nil? && @from_email_address.to_s.length < 0 return false if @name.nil? return false if @name.to_s.length > 100 return false if @name.to_s.length < 0 return false if @organization_name.nil? return false if @organization_name.to_s.length > 255 return false if @organization_name.to_s.length < 0 return false if !@phone_number.nil? && @phone_number.to_s.length > 25 return false if !@phone_number.nil? && @phone_number.to_s.length < 1 true end |