Class: ConstantContactClient::CreateContactRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/constant_contact_client/models/create_contact_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateContactRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ConstantContactClient::CreateContactRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ConstantContactClient::CreateContactRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'email_address')
    self.email_address = attributes[:'email_address']
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  end

  if attributes.key?(:'job_title')
    self.job_title = attributes[:'job_title']
  end

  if attributes.key?(:'company_name')
    self.company_name = attributes[:'company_name']
  end

  if attributes.key?(:'create_source')
    self.create_source = attributes[:'create_source']
  end

  if attributes.key?(:'birthday_month')
    self.birthday_month = attributes[:'birthday_month']
  end

  if attributes.key?(:'birthday_day')
    self.birthday_day = attributes[:'birthday_day']
  end

  if attributes.key?(:'anniversary')
    self.anniversary = attributes[:'anniversary']
  end

  if attributes.key?(:'custom_fields')
    if (value = attributes[:'custom_fields']).is_a?(Array)
      self.custom_fields = value
    end
  end

  if attributes.key?(:'phone_numbers')
    if (value = attributes[:'phone_numbers']).is_a?(Array)
      self.phone_numbers = value
    end
  end

  if attributes.key?(:'street_addresses')
    if (value = attributes[:'street_addresses']).is_a?(Array)
      self.street_addresses = value
    end
  end

  if attributes.key?(:'list_memberships')
    if (value = attributes[:'list_memberships']).is_a?(Array)
      self.list_memberships = value
    end
  end

  if attributes.key?(:'taggings')
    if (value = attributes[:'taggings']).is_a?(Array)
      self.taggings = value
    end
  end

  if attributes.key?(:'notes')
    if (value = attributes[:'notes']).is_a?(Array)
      self.notes = value
    end
  end

  if attributes.key?(:'sms_channel')
    self.sms_channel = attributes[:'sms_channel']
  end
end

Instance Attribute Details

#anniversaryObject

The anniversary date for the contact. For example, this value could be the date when the contact first became a customer of an organization in Constant Contact. Valid date formats are MM/DD/YYYY, M/D/YYYY, YYYY/MM/DD, YYYY/M/D, YYYY-MM-DD, YYYY-M-D,M-D-YYYY, or M-DD-YYYY.



42
43
44
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 42

def anniversary
  @anniversary
end

#birthday_dayObject

The day value for the contact's birthday. Valid values are from 1 through 31. The birthday_day property is required if you use birthday_month.



39
40
41
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 39

def birthday_day
  @birthday_day
end

#birthday_monthObject

The month value for the contact's birthday. Valid values are from 1 through 12. The birthday_month property is required if you use birthday_day.



36
37
38
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 36

def birthday_month
  @birthday_month
end

#company_nameObject

The name of the company where the contact works.



30
31
32
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 30

def company_name
  @company_name
end

#create_sourceObject

Describes who added the contact; valid values are Contact or Account. Your integration must accurately identify create_source for compliance reasons; value is set on POST, and is read-only going forward.



33
34
35
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 33

def create_source
  @create_source
end

#custom_fieldsObject

Array of up to 25 custom_field key value pairs.



45
46
47
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 45

def custom_fields
  @custom_fields
end

#email_addressObject

Returns the value of attribute email_address.



18
19
20
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 18

def email_address
  @email_address
end

#first_nameObject

The first name of the contact.



21
22
23
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 21

def first_name
  @first_name
end

#job_titleObject

The job title of the contact.



27
28
29
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 27

def job_title
  @job_title
end

#last_nameObject

The last name of the contact.



24
25
26
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 24

def last_name
  @last_name
end

#list_membershipsObject

Array of list_ids to which the contact is being subscribed, up to a maximum of 50.



54
55
56
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 54

def list_memberships
  @list_memberships
end

#notesObject

An array of notes about the contact.



60
61
62
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 60

def notes
  @notes
end

#phone_numbersObject

Array of up to 3 phone numbers subresources.



48
49
50
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 48

def phone_numbers
  @phone_numbers
end

#sms_channelObject

Returns the value of attribute sms_channel.



62
63
64
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 62

def sms_channel
  @sms_channel
end

#street_addressesObject

Array of up to 3 street address subresources.



51
52
53
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 51

def street_addresses
  @street_addresses
end

#taggingsObject

Array of tags (tag_id) assigned to the contact, up to a maximum of 50.



57
58
59
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 57

def taggings
  @taggings
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 497

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = ConstantContactClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



87
88
89
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 87

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 65

def self.attribute_map
  {
    :'email_address' => :'email_address',
    :'first_name' => :'first_name',
    :'last_name' => :'last_name',
    :'job_title' => :'job_title',
    :'company_name' => :'company_name',
    :'create_source' => :'create_source',
    :'birthday_month' => :'birthday_month',
    :'birthday_day' => :'birthday_day',
    :'anniversary' => :'anniversary',
    :'custom_fields' => :'custom_fields',
    :'phone_numbers' => :'phone_numbers',
    :'street_addresses' => :'street_addresses',
    :'list_memberships' => :'list_memberships',
    :'taggings' => :'taggings',
    :'notes' => :'notes',
    :'sms_channel' => :'sms_channel'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 473

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



114
115
116
117
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 114

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 92

def self.openapi_types
  {
    :'email_address' => :'CreateContactRequestEmailAddress',
    :'first_name' => :'String',
    :'last_name' => :'String',
    :'job_title' => :'String',
    :'company_name' => :'String',
    :'create_source' => :'String',
    :'birthday_month' => :'Integer',
    :'birthday_day' => :'Integer',
    :'anniversary' => :'String',
    :'custom_fields' => :'Array<GetContactById200ResponseCustomFieldsInner>',
    :'phone_numbers' => :'Array<UpdateContactRequestPhoneNumbersInner>',
    :'street_addresses' => :'Array<UpdateContactRequestStreetAddressesInner>',
    :'list_memberships' => :'Array<String>',
    :'taggings' => :'Array<String>',
    :'notes' => :'Array<GetContactById200ResponseNotesInner>',
    :'sms_channel' => :'UpdateContactRequestSmsChannel'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 437

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      email_address == o.email_address &&
      first_name == o.first_name &&
      last_name == o.last_name &&
      job_title == o.job_title &&
      company_name == o.company_name &&
      create_source == o.create_source &&
      birthday_month == o.birthday_month &&
      birthday_day == o.birthday_day &&
      anniversary == o.anniversary &&
      custom_fields == o.custom_fields &&
      phone_numbers == o.phone_numbers &&
      street_addresses == o.street_addresses &&
      list_memberships == o.list_memberships &&
      taggings == o.taggings &&
      notes == o.notes &&
      sms_channel == o.sms_channel
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



568
569
570
571
572
573
574
575
576
577
578
579
580
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 568

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


460
461
462
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 460

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



466
467
468
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 466

def hash
  [email_address, first_name, last_name, job_title, company_name, create_source, birthday_month, birthday_day, anniversary, custom_fields, phone_numbers, street_addresses, list_memberships, taggings, notes, sms_channel].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 213

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@first_name.nil? && @first_name.to_s.length > 50
    invalid_properties.push('invalid value for "first_name", the character length must be smaller than or equal to 50.')
  end

  if !@last_name.nil? && @last_name.to_s.length > 50
    invalid_properties.push('invalid value for "last_name", the character length must be smaller than or equal to 50.')
  end

  if !@job_title.nil? && @job_title.to_s.length > 50
    invalid_properties.push('invalid value for "job_title", the character length must be smaller than or equal to 50.')
  end

  if !@company_name.nil? && @company_name.to_s.length > 50
    invalid_properties.push('invalid value for "company_name", the character length must be smaller than or equal to 50.')
  end

  if !@anniversary.nil? && @anniversary.to_s.length > 10
    invalid_properties.push('invalid value for "anniversary", the character length must be smaller than or equal to 10.')
  end

  if !@custom_fields.nil? && @custom_fields.length > 25
    invalid_properties.push('invalid value for "custom_fields", number of items must be less than or equal to 25.')
  end

  if !@phone_numbers.nil? && @phone_numbers.length > 3
    invalid_properties.push('invalid value for "phone_numbers", number of items must be less than or equal to 3.')
  end

  if !@street_addresses.nil? && @street_addresses.length > 3
    invalid_properties.push('invalid value for "street_addresses", number of items must be less than or equal to 3.')
  end

  if !@list_memberships.nil? && @list_memberships.length > 50
    invalid_properties.push('invalid value for "list_memberships", number of items must be less than or equal to 50.')
  end

  if !@taggings.nil? && @taggings.length > 50
    invalid_properties.push('invalid value for "taggings", number of items must be less than or equal to 50.')
  end

  if !@notes.nil? && @notes.length > 150
    invalid_properties.push('invalid value for "notes", number of items must be less than or equal to 150.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



544
545
546
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 544

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



550
551
552
553
554
555
556
557
558
559
560
561
562
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 550

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



538
539
540
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 538

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/constant_contact_client/models/create_contact_request.rb', line 265

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@first_name.nil? && @first_name.to_s.length > 50
  return false if !@last_name.nil? && @last_name.to_s.length > 50
  return false if !@job_title.nil? && @job_title.to_s.length > 50
  return false if !@company_name.nil? && @company_name.to_s.length > 50
  return false if !@anniversary.nil? && @anniversary.to_s.length > 10
  return false if !@custom_fields.nil? && @custom_fields.length > 25
  return false if !@phone_numbers.nil? && @phone_numbers.length > 3
  return false if !@street_addresses.nil? && @street_addresses.length > 3
  return false if !@list_memberships.nil? && @list_memberships.length > 50
  return false if !@taggings.nil? && @taggings.length > 50
  return false if !@notes.nil? && @notes.length > 150
  true
end