Class: ConstantContactClient::CreateOrUpdateContactRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/constant_contact_client/models/create_or_update_contact_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateOrUpdateContactRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 106

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ConstantContactClient::CreateOrUpdateContactRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ConstantContactClient::CreateOrUpdateContactRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'email_address')
    self.email_address = attributes[:'email_address']
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  end

  if attributes.key?(:'job_title')
    self.job_title = attributes[:'job_title']
  end

  if attributes.key?(:'company_name')
    self.company_name = attributes[:'company_name']
  end

  if attributes.key?(:'phone_number')
    self.phone_number = attributes[:'phone_number']
  end

  if attributes.key?(:'list_memberships')
    if (value = attributes[:'list_memberships']).is_a?(Array)
      self.list_memberships = value
    end
  else
    self.list_memberships = nil
  end

  if attributes.key?(:'custom_fields')
    if (value = attributes[:'custom_fields']).is_a?(Array)
      self.custom_fields = value
    end
  end

  if attributes.key?(:'anniversary')
    self.anniversary = attributes[:'anniversary']
  end

  if attributes.key?(:'birthday_month')
    self.birthday_month = attributes[:'birthday_month']
  end

  if attributes.key?(:'birthday_day')
    self.birthday_day = attributes[:'birthday_day']
  end

  if attributes.key?(:'street_address')
    self.street_address = attributes[:'street_address']
  end

  if attributes.key?(:'sms_channel')
    self.sms_channel = attributes[:'sms_channel']
  end
end

Instance Attribute Details

#anniversaryObject

The anniversary date for the contact. For example, this value could be the date when the contact first became a customer of an organization in Constant Contact. Valid date formats are MM/DD/YYYY, M/D/YYYY, YYYY/MM/DD, YYYY/M/D, YYYY-MM-DD, YYYY-M-D,M-D-YYYY, or M-DD-YYYY.



43
44
45
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 43

def anniversary
  @anniversary
end

#birthday_dayObject

The day value for the contact's birthday. Valid values are from 1 through 31. The birthday_day property is required if you use birthday_month.



49
50
51
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 49

def birthday_day
  @birthday_day
end

#birthday_monthObject

The month value for the contact's birthday. Valid values are from 1 through 12. The birthday_month property is required if you use birthday_day.



46
47
48
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 46

def birthday_month
  @birthday_month
end

#company_nameObject

The name of the company where the contact works.



31
32
33
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 31

def company_name
  @company_name
end

#custom_fieldsObject

The custom fields you want to add to the contact as an array of up to 50 custom field objects.



40
41
42
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 40

def custom_fields
  @custom_fields
end

#email_addressObject

The email address for the contact. This method identifies each unique contact using their email address. If the email address exists in the account, this method updates the contact. If the email address is new, this method creates a new contact.



19
20
21
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 19

def email_address
  @email_address
end

#first_nameObject

The first name of the contact.



22
23
24
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 22

def first_name
  @first_name
end

#job_titleObject

The job title of the contact.



28
29
30
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 28

def job_title
  @job_title
end

#last_nameObject

The last name of the contact.



25
26
27
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 25

def last_name
  @last_name
end

#list_membershipsObject

The contact lists you want to add the contact to as an array of up to 50 contact list_id values. You must include at least one list_id.



37
38
39
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 37

def list_memberships
  @list_memberships
end

#phone_numberObject

The phone number for the contact.



34
35
36
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 34

def phone_number
  @phone_number
end

#sms_channelObject

Returns the value of attribute sms_channel.



53
54
55
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 53

def sms_channel
  @sms_channel
end

#street_addressObject

Returns the value of attribute street_address.



51
52
53
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 51

def street_address
  @street_address
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 418

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = ConstantContactClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 75

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 56

def self.attribute_map
  {
    :'email_address' => :'email_address',
    :'first_name' => :'first_name',
    :'last_name' => :'last_name',
    :'job_title' => :'job_title',
    :'company_name' => :'company_name',
    :'phone_number' => :'phone_number',
    :'list_memberships' => :'list_memberships',
    :'custom_fields' => :'custom_fields',
    :'anniversary' => :'anniversary',
    :'birthday_month' => :'birthday_month',
    :'birthday_day' => :'birthday_day',
    :'street_address' => :'street_address',
    :'sms_channel' => :'sms_channel'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 394

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



99
100
101
102
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 99

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 80

def self.openapi_types
  {
    :'email_address' => :'String',
    :'first_name' => :'String',
    :'last_name' => :'String',
    :'job_title' => :'String',
    :'company_name' => :'String',
    :'phone_number' => :'String',
    :'list_memberships' => :'Array<String>',
    :'custom_fields' => :'Array<CreateOrUpdateContactRequestCustomFieldsInner>',
    :'anniversary' => :'String',
    :'birthday_month' => :'Integer',
    :'birthday_day' => :'Integer',
    :'street_address' => :'CreateOrUpdateContactRequestStreetAddress',
    :'sms_channel' => :'CreateOrUpdateContactRequestSmsChannel'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 361

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      email_address == o.email_address &&
      first_name == o.first_name &&
      last_name == o.last_name &&
      job_title == o.job_title &&
      company_name == o.company_name &&
      phone_number == o.phone_number &&
      list_memberships == o.list_memberships &&
      custom_fields == o.custom_fields &&
      anniversary == o.anniversary &&
      birthday_month == o.birthday_month &&
      birthday_day == o.birthday_day &&
      street_address == o.street_address &&
      sms_channel == o.sms_channel
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 489

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


381
382
383
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 381

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



387
388
389
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 387

def hash
  [email_address, first_name, last_name, job_title, company_name, phone_number, list_memberships, custom_fields, anniversary, birthday_month, birthday_day, street_address, sms_channel].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 180

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@email_address.nil? && @email_address.to_s.length > 50
    invalid_properties.push('invalid value for "email_address", the character length must be smaller than or equal to 50.')
  end

  if !@first_name.nil? && @first_name.to_s.length > 50
    invalid_properties.push('invalid value for "first_name", the character length must be smaller than or equal to 50.')
  end

  if !@last_name.nil? && @last_name.to_s.length > 50
    invalid_properties.push('invalid value for "last_name", the character length must be smaller than or equal to 50.')
  end

  if !@job_title.nil? && @job_title.to_s.length > 50
    invalid_properties.push('invalid value for "job_title", the character length must be smaller than or equal to 50.')
  end

  if !@company_name.nil? && @company_name.to_s.length > 50
    invalid_properties.push('invalid value for "company_name", the character length must be smaller than or equal to 50.')
  end

  if !@phone_number.nil? && @phone_number.to_s.length > 25
    invalid_properties.push('invalid value for "phone_number", the character length must be smaller than or equal to 25.')
  end

  if @list_memberships.nil?
    invalid_properties.push('invalid value for "list_memberships", list_memberships cannot be nil.')
  end

  if @list_memberships.length > 50
    invalid_properties.push('invalid value for "list_memberships", number of items must be less than or equal to 50.')
  end

  if @list_memberships.length < 1
    invalid_properties.push('invalid value for "list_memberships", number of items must be greater than or equal to 1.')
  end

  if !@custom_fields.nil? && @custom_fields.length > 50
    invalid_properties.push('invalid value for "custom_fields", number of items must be less than or equal to 50.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



465
466
467
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 465

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



471
472
473
474
475
476
477
478
479
480
481
482
483
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 471

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



459
460
461
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 459

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/constant_contact_client/models/create_or_update_contact_request.rb', line 228

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@email_address.nil? && @email_address.to_s.length > 50
  return false if !@first_name.nil? && @first_name.to_s.length > 50
  return false if !@last_name.nil? && @last_name.to_s.length > 50
  return false if !@job_title.nil? && @job_title.to_s.length > 50
  return false if !@company_name.nil? && @company_name.to_s.length > 50
  return false if !@phone_number.nil? && @phone_number.to_s.length > 25
  return false if @list_memberships.nil?
  return false if @list_memberships.length > 50
  return false if @list_memberships.length < 1
  return false if !@custom_fields.nil? && @custom_fields.length > 50
  true
end