Class: ConstantContactClient::GetCustomField200Response
- Inherits:
-
Object
- Object
- ConstantContactClient::GetCustomField200Response
- Defined in:
- lib/constant_contact_client/models/get_custom_field200_response.rb
Overview
Custom fields details.
Instance Attribute Summary collapse
-
#choices ⇒ Object
Choices available for
single_selectandmulti_selecttype custom fields. -
#created_at ⇒ Object
Date and time that the resource was created, in ISO-8601 format.
-
#custom_field_id ⇒ Object
The system generated ID that uniquely identifies a
custom_field. -
#label ⇒ Object
The custom field name to display in the UI (free-form text).
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#name ⇒ Object
The unique custom field name constructed from the label by replacing blanks with underscores.
-
#type ⇒ Object
The data value type the custom field accepts.
-
#updated_at ⇒ Object
System generated date and time that the resource was updated, in ISO-8601 format.
-
#version ⇒ Object
For
datetimedata types, this is the version number associated with the custom field.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetCustomField200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ GetCustomField200Response
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ConstantContactClient::GetCustomField200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ConstantContactClient::GetCustomField200Response`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'custom_field_id') self.custom_field_id = attributes[:'custom_field_id'] end if attributes.key?(:'label') self.label = attributes[:'label'] else self.label = nil end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end if attributes.key?(:'version') self.version = attributes[:'version'] end if attributes.key?(:'choices') if (value = attributes[:'choices']).is_a?(Array) self.choices = value end end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end end |
Instance Attribute Details
#choices ⇒ Object
Choices available for single_select and multi_select type custom fields. The maximum number of elements for radio or checkbox display types is 20. Maximum number of elements for a dropdown is 100.
37 38 39 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 37 def choices @choices end |
#created_at ⇒ Object
Date and time that the resource was created, in ISO-8601 format. System generated.
43 44 45 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 43 def created_at @created_at end |
#custom_field_id ⇒ Object
The system generated ID that uniquely identifies a custom_field.
20 21 22 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 20 def custom_field_id @custom_field_id end |
#label ⇒ Object
The custom field name to display in the UI (free-form text).
23 24 25 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 23 def label @label end |
#metadata ⇒ Object
Returns the value of attribute metadata.
31 32 33 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 31 def @metadata end |
#name ⇒ Object
The unique custom field name constructed from the label by replacing blanks with underscores.
26 27 28 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 26 def name @name end |
#type ⇒ Object
The data value type the custom field accepts.
29 30 31 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 29 def type @type end |
#updated_at ⇒ Object
System generated date and time that the resource was updated, in ISO-8601 format.
40 41 42 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 40 def updated_at @updated_at end |
#version ⇒ Object
For datetime data types, this is the version number associated with the custom field.
34 35 36 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 34 def version @version end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 300 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = ConstantContactClient.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 61 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 46 def self.attribute_map { :'custom_field_id' => :'custom_field_id', :'label' => :'label', :'name' => :'name', :'type' => :'type', :'metadata' => :'metadata', :'version' => :'version', :'choices' => :'choices', :'updated_at' => :'updated_at', :'created_at' => :'created_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 276 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 66 def self.openapi_types { :'custom_field_id' => :'String', :'label' => :'String', :'name' => :'String', :'type' => :'String', :'metadata' => :'GetCustomField200ResponseMetadata', :'version' => :'Integer', :'choices' => :'Array<GetCustomField200ResponseChoicesInner>', :'updated_at' => :'Time', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 247 def ==(o) return true if self.equal?(o) self.class == o.class && custom_field_id == o.custom_field_id && label == o.label && name == o.name && type == o.type && == o. && version == o.version && choices == o.choices && updated_at == o.updated_at && created_at == o.created_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 371 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
263 264 265 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 263 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
269 270 271 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 269 def hash [custom_field_id, label, name, type, , version, choices, updated_at, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 146 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @label.nil? invalid_properties.push('invalid value for "label", label cannot be nil.') end if @label.to_s.length > 50 invalid_properties.push('invalid value for "label", the character length must be smaller than or equal to 50.') end if !@name.nil? && @name.to_s.length > 50 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 50.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @type.to_s.length > 20 invalid_properties.push('invalid value for "type", the character length must be smaller than or equal to 20.') end if !@choices.nil? && @choices.length > 100 invalid_properties.push('invalid value for "choices", number of items must be less than or equal to 100.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
347 348 349 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 347 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 353 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
341 342 343 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 341 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
178 179 180 181 182 183 184 185 186 187 |
# File 'lib/constant_contact_client/models/get_custom_field200_response.rb', line 178 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @label.nil? return false if @label.to_s.length > 50 return false if !@name.nil? && @name.to_s.length > 50 return false if @type.nil? return false if @type.to_s.length > 20 return false if !@choices.nil? && @choices.length > 100 true end |