Class: ConstantContactClient::GetRegistrationInfo200ResponseOrderSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ GetRegistrationInfo200ResponseOrderSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 87

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ConstantContactClient::GetRegistrationInfo200ResponseOrderSummary` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ConstantContactClient::GetRegistrationInfo200ResponseOrderSummary`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'details')
    if (value = attributes[:'details']).is_a?(Array)
      self.details = value
    end
  end

  if attributes.key?(:'number')
    self.number = attributes[:'number']
  end

  if attributes.key?(:'payment_method')
    self.payment_method = attributes[:'payment_method']
  end

  if attributes.key?(:'payment_status')
    self.payment_status = attributes[:'payment_status']
  end

  if attributes.key?(:'payment_time')
    self.payment_time = attributes[:'payment_time']
  end

  if attributes.key?(:'payment_transaction_id')
    self.payment_transaction_id = attributes[:'payment_transaction_id']
  end

  if attributes.key?(:'tickets_link')
    self.tickets_link = attributes[:'tickets_link']
  end

  if attributes.key?(:'tickets_text')
    self.tickets_text = attributes[:'tickets_text']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end
end

Instance Attribute Details

#detailsObject

Returns the value of attribute details.



18
19
20
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 18

def details
  @details
end

#numberObject

The system assigned string value used to identify the event order.



21
22
23
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 21

def number
  @number
end

#payment_methodObject

The payment method used when the order was placed. Acceptable payment methods include; STRIPE and PAYPAL.



24
25
26
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 24

def payment_method
  @payment_method
end

#payment_statusObject

The event registration payment status. Acceptable values include; PENDING, PAID, REFUNDED, CANCELLED, FAILED, CHARGED_BACK, PENDING, UNKNOWN</code.



27
28
29
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 27

def payment_status
  @payment_status
end

#payment_timeObject

Displays the date and time the payment was made, in ISO format.



30
31
32
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 30

def payment_time
  @payment_time
end

#payment_transaction_idObject

The unique ID used to identify a payment transaction.



33
34
35
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 33

def payment_transaction_id
  @payment_transaction_id
end

The URL used to access purchased tickets.



36
37
38
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 36

def tickets_link
  @tickets_link
end

#tickets_textObject

Text that describes the event and ticket information.



39
40
41
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 39

def tickets_text
  @tickets_text
end

#titleObject

The title for the order.



42
43
44
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 42

def title
  @title
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 209

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = ConstantContactClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 60

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 45

def self.attribute_map
  {
    :'details' => :'details',
    :'number' => :'number',
    :'payment_method' => :'payment_method',
    :'payment_status' => :'payment_status',
    :'payment_time' => :'payment_time',
    :'payment_transaction_id' => :'payment_transaction_id',
    :'tickets_link' => :'tickets_link',
    :'tickets_text' => :'tickets_text',
    :'title' => :'title'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 185

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



80
81
82
83
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 80

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 65

def self.openapi_types
  {
    :'details' => :'Array<GetRegistrationInfo200ResponseOrderSummaryDetailsInner>',
    :'number' => :'String',
    :'payment_method' => :'String',
    :'payment_status' => :'String',
    :'payment_time' => :'String',
    :'payment_transaction_id' => :'String',
    :'tickets_link' => :'String',
    :'tickets_text' => :'String',
    :'title' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 156

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      details == o.details &&
      number == o.number &&
      payment_method == o.payment_method &&
      payment_status == o.payment_status &&
      payment_time == o.payment_time &&
      payment_transaction_id == o.payment_transaction_id &&
      tickets_link == o.tickets_link &&
      tickets_text == o.tickets_text &&
      title == o.title
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 280

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


172
173
174
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 172

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



178
179
180
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 178

def hash
  [details, number, payment_method, payment_status, payment_time, payment_transaction_id, tickets_link, tickets_text, title].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



141
142
143
144
145
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 141

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



256
257
258
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 256

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 262

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



250
251
252
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 250

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



149
150
151
152
# File 'lib/constant_contact_client/models/get_registration_info200_response_order_summary.rb', line 149

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end