Class: ConstantContactClient::ItemDto
- Inherits:
-
Object
- Object
- ConstantContactClient::ItemDto
- Defined in:
- lib/constant_contact_client/models/item_dto.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
Returns the value of attribute attributes.
-
#create_time ⇒ Object
The create time of the event is ISO format.
-
#deletable_flag ⇒ Object
Specifies if the item can be deleted.
-
#deleted_time ⇒ Object
The time when the item was deleted.
-
#description ⇒ Object
The description of the item.
-
#display_order ⇒ Object
The order in which to display an item.
-
#end_time ⇒ Object
The time that the item become unavailable.
-
#hidden_flag ⇒ Object
Specifies if the item is hidden from customers.
-
#item_id ⇒ Object
The unique identifier for the item.
-
#last_update_time ⇒ Object
Last modification time of the event.
-
#limit_per_order ⇒ Object
Limits the number of items per order.
-
#media_internal_id ⇒ Object
The internal identifier for the item's image.
-
#media_url ⇒ Object
The URL to associate with the media.
-
#name ⇒ Object
The name of the item.
-
#paused_flag ⇒ Object
Specifies if the item is currently paused from sales.
-
#price ⇒ Object
The price per item.
-
#quantity_remaining ⇒ Object
The total number of items still available.
-
#quantity_sold ⇒ Object
The total number of items sold.
-
#quantity_total ⇒ Object
The total number of items available.
-
#show_remaining_flag ⇒ Object
Set to display or not to display the number of remaining items to customers.
-
#start_time ⇒ Object
The start time when the item becomes available.
-
#status_labels ⇒ Object
Returns the value of attribute status_labels.
-
#time_limit_flag ⇒ Object
Specifies if the item has time-based availability.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ItemDto
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ItemDto
Initializes the object
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 156 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ConstantContactClient::ItemDto` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ConstantContactClient::ItemDto`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'create_time') self.create_time = attributes[:'create_time'] end if attributes.key?(:'last_update_time') self.last_update_time = attributes[:'last_update_time'] end if attributes.key?(:'item_id') self.item_id = attributes[:'item_id'] end if attributes.key?(:'display_order') self.display_order = attributes[:'display_order'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'price') self.price = attributes[:'price'] end if attributes.key?(:'quantity_total') self.quantity_total = attributes[:'quantity_total'] end if attributes.key?(:'quantity_remaining') self.quantity_remaining = attributes[:'quantity_remaining'] end if attributes.key?(:'quantity_sold') self.quantity_sold = attributes[:'quantity_sold'] end if attributes.key?(:'limit_per_order') self.limit_per_order = attributes[:'limit_per_order'] end if attributes.key?(:'show_remaining_flag') self.show_remaining_flag = attributes[:'show_remaining_flag'] end if attributes.key?(:'paused_flag') self.paused_flag = attributes[:'paused_flag'] end if attributes.key?(:'deletable_flag') self.deletable_flag = attributes[:'deletable_flag'] end if attributes.key?(:'media_internal_id') self.media_internal_id = attributes[:'media_internal_id'] end if attributes.key?(:'media_url') self.media_url = attributes[:'media_url'] end if attributes.key?(:'time_limit_flag') self.time_limit_flag = attributes[:'time_limit_flag'] end if attributes.key?(:'start_time') self.start_time = attributes[:'start_time'] end if attributes.key?(:'end_time') self.end_time = attributes[:'end_time'] end if attributes.key?(:'hidden_flag') self.hidden_flag = attributes[:'hidden_flag'] end if attributes.key?(:'deleted_time') self.deleted_time = attributes[:'deleted_time'] end if attributes.key?(:'status_labels') if (value = attributes[:'status_labels']).is_a?(Array) self.status_labels = value end end if attributes.key?(:'attributes') if (value = attributes[:'attributes']).is_a?(Array) self.attributes = value end end end |
Instance Attribute Details
#attributes ⇒ Object
Returns the value of attribute attributes.
83 84 85 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 83 def attributes @attributes end |
#create_time ⇒ Object
The create time of the event is ISO format.
19 20 21 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 19 def create_time @create_time end |
#deletable_flag ⇒ Object
Specifies if the item can be deleted.
58 59 60 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 58 def deletable_flag @deletable_flag end |
#deleted_time ⇒ Object
The time when the item was deleted.
79 80 81 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 79 def deleted_time @deleted_time end |
#description ⇒ Object
The description of the item.
34 35 36 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 34 def description @description end |
#display_order ⇒ Object
The order in which to display an item.
28 29 30 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 28 def display_order @display_order end |
#end_time ⇒ Object
The time that the item become unavailable.
73 74 75 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 73 def end_time @end_time end |
#hidden_flag ⇒ Object
Specifies if the item is hidden from customers.
76 77 78 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 76 def hidden_flag @hidden_flag end |
#item_id ⇒ Object
The unique identifier for the item.
25 26 27 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 25 def item_id @item_id end |
#last_update_time ⇒ Object
Last modification time of the event.
22 23 24 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 22 def last_update_time @last_update_time end |
#limit_per_order ⇒ Object
Limits the number of items per order.
49 50 51 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 49 def limit_per_order @limit_per_order end |
#media_internal_id ⇒ Object
The internal identifier for the item's image.
61 62 63 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 61 def media_internal_id @media_internal_id end |
#media_url ⇒ Object
The URL to associate with the media.
64 65 66 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 64 def media_url @media_url end |
#name ⇒ Object
The name of the item.
31 32 33 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 31 def name @name end |
#paused_flag ⇒ Object
Specifies if the item is currently paused from sales.
55 56 57 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 55 def paused_flag @paused_flag end |
#price ⇒ Object
The price per item.
37 38 39 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 37 def price @price end |
#quantity_remaining ⇒ Object
The total number of items still available.
43 44 45 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 43 def quantity_remaining @quantity_remaining end |
#quantity_sold ⇒ Object
The total number of items sold.
46 47 48 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 46 def quantity_sold @quantity_sold end |
#quantity_total ⇒ Object
The total number of items available.
40 41 42 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 40 def quantity_total @quantity_total end |
#show_remaining_flag ⇒ Object
Set to display or not to display the number of remaining items to customers.
52 53 54 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 52 def show_remaining_flag @show_remaining_flag end |
#start_time ⇒ Object
The start time when the item becomes available.
70 71 72 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 70 def start_time @start_time end |
#status_labels ⇒ Object
Returns the value of attribute status_labels.
81 82 83 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 81 def status_labels @status_labels end |
#time_limit_flag ⇒ Object
Specifies if the item has time-based availability.
67 68 69 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 67 def time_limit_flag @time_limit_flag end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 357 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = ConstantContactClient.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
115 116 117 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 115 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 86 def self.attribute_map { :'create_time' => :'create_time', :'last_update_time' => :'last_update_time', :'item_id' => :'item_id', :'display_order' => :'display_order', :'name' => :'name', :'description' => :'description', :'price' => :'price', :'quantity_total' => :'quantity_total', :'quantity_remaining' => :'quantity_remaining', :'quantity_sold' => :'quantity_sold', :'limit_per_order' => :'limit_per_order', :'show_remaining_flag' => :'show_remaining_flag', :'paused_flag' => :'paused_flag', :'deletable_flag' => :'deletable_flag', :'media_internal_id' => :'media_internal_id', :'media_url' => :'media_url', :'time_limit_flag' => :'time_limit_flag', :'start_time' => :'start_time', :'end_time' => :'end_time', :'hidden_flag' => :'hidden_flag', :'deleted_time' => :'deleted_time', :'status_labels' => :'status_labels', :'attributes' => :'attributes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 333 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
149 150 151 152 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 149 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 120 def self.openapi_types { :'create_time' => :'String', :'last_update_time' => :'String', :'item_id' => :'String', :'display_order' => :'Integer', :'name' => :'String', :'description' => :'String', :'price' => :'Float', :'quantity_total' => :'Integer', :'quantity_remaining' => :'Integer', :'quantity_sold' => :'Integer', :'limit_per_order' => :'Integer', :'show_remaining_flag' => :'Boolean', :'paused_flag' => :'Boolean', :'deletable_flag' => :'Boolean', :'media_internal_id' => :'String', :'media_url' => :'String', :'time_limit_flag' => :'Boolean', :'start_time' => :'String', :'end_time' => :'String', :'hidden_flag' => :'Boolean', :'deleted_time' => :'String', :'status_labels' => :'Array<StatusDisplayLabelDto1>', :'attributes' => :'Array<AttributeDto1>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 290 def ==(o) return true if self.equal?(o) self.class == o.class && create_time == o.create_time && last_update_time == o.last_update_time && item_id == o.item_id && display_order == o.display_order && name == o.name && description == o.description && price == o.price && quantity_total == o.quantity_total && quantity_remaining == o.quantity_remaining && quantity_sold == o.quantity_sold && limit_per_order == o.limit_per_order && show_remaining_flag == o.show_remaining_flag && paused_flag == o.paused_flag && deletable_flag == o.deletable_flag && media_internal_id == o.media_internal_id && media_url == o.media_url && time_limit_flag == o.time_limit_flag && start_time == o.start_time && end_time == o.end_time && hidden_flag == o.hidden_flag && deleted_time == o.deleted_time && status_labels == o.status_labels && attributes == o.attributes end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
428 429 430 431 432 433 434 435 436 437 438 439 440 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 428 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
320 321 322 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 320 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
326 327 328 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 326 def hash [create_time, last_update_time, item_id, display_order, name, description, price, quantity_total, quantity_remaining, quantity_sold, limit_per_order, show_remaining_flag, paused_flag, deletable_flag, media_internal_id, media_url, time_limit_flag, start_time, end_time, hidden_flag, deleted_time, status_labels, attributes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
270 271 272 273 274 275 276 277 278 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 270 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
404 405 406 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 404 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
410 411 412 413 414 415 416 417 418 419 420 421 422 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 410 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
398 399 400 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 398 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
282 283 284 285 286 |
# File 'lib/constant_contact_client/models/item_dto.rb', line 282 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? true end |