Class: ConstantContactClient::ProfileDto

Inherits:
Object
  • Object
show all
Defined in:
lib/constant_contact_client/models/profile_dto.rb

Overview

Describes a social network profile (Business Page, Company Page/Organization, etc.).
Note: Due to performance and/or rate-limit issues, some properties may be cached. Where possible, caching will be limited to 15 minutes.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ProfileDto

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/constant_contact_client/models/profile_dto.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ConstantContactClient::ProfileDto` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ConstantContactClient::ProfileDto`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'accessible')
    self.accessible = attributes[:'accessible']
  end

  if attributes.key?(:'account_info')
    self. = attributes[:'account_info']
  end

  if attributes.key?(:'connected')
    self.connected = attributes[:'connected']
  else
    self.connected = nil
  end

  if attributes.key?(:'handle')
    self.handle = attributes[:'handle']
  end

  if attributes.key?(:'image_url')
    self.image_url = attributes[:'image_url']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'network')
    self.network = attributes[:'network']
  else
    self.network = nil
  end

  if attributes.key?(:'network_profile_id')
    self.network_profile_id = attributes[:'network_profile_id']
  end

  if attributes.key?(:'network_user_id')
    self.network_user_id = attributes[:'network_user_id']
  end

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  else
    self.profile_id = nil
  end

  if attributes.key?(:'settings')
    if (value = attributes[:'settings']).is_a?(Hash)
      self.settings = value
    end
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end
end

Instance Attribute Details

#accessibleObject

Whether the profile is currently accessible for posting. Publishing a post will fail if its profile is not currently accessible. Only populated when the GET request includes the query parameter include=accessible.



20
21
22
# File 'lib/constant_contact_client/models/profile_dto.rb', line 20

def accessible
  @accessible
end

#account_infoObject

Returns the value of attribute account_info.



22
23
24
# File 'lib/constant_contact_client/models/profile_dto.rb', line 22

def 
  @account_info
end

#connectedObject

Whether this profile is currently connected. You can only create and publish posts with connected profiles.



25
26
27
# File 'lib/constant_contact_client/models/profile_dto.rb', line 25

def connected
  @connected
end

#handleObject

The profile's handle on the social network (for example, an Instagram or TikTok username). May be null if the network does not expose a separate handle (for example, Facebook).



28
29
30
# File 'lib/constant_contact_client/models/profile_dto.rb', line 28

def handle
  @handle
end

#image_urlObject

URL of the profile's image or avatar.



31
32
33
# File 'lib/constant_contact_client/models/profile_dto.rb', line 31

def image_url
  @image_url
end

#nameObject

Display name of the profile.



34
35
36
# File 'lib/constant_contact_client/models/profile_dto.rb', line 34

def name
  @name
end

#networkObject

The social network this profile belongs to.



37
38
39
# File 'lib/constant_contact_client/models/profile_dto.rb', line 37

def network
  @network
end

#network_profile_idObject

The social network-specific identifier for this profile.



40
41
42
# File 'lib/constant_contact_client/models/profile_dto.rb', line 40

def network_profile_id
  @network_profile_id
end

#network_user_idObject

The social network-specific identifier for the user who owns this profile.



43
44
45
# File 'lib/constant_contact_client/models/profile_dto.rb', line 43

def network_user_id
  @network_user_id
end

#profile_idObject

Unique identifier for this profile. Use this value in the profile_id field of a ProfilePost when creating a post.



46
47
48
# File 'lib/constant_contact_client/models/profile_dto.rb', line 46

def profile_id
  @profile_id
end

#settingsObject

Network-specific settings for the profile. Only populated when the request includes include=accessible and settings are available for the network. Currently, only TikTok provides settings:

"content": {   "comment_disabled": Boolean,   "duet_disabled": Boolean,   "stitch_disabled": Boolean,   "max_video_post_duration_sec": Integer }



49
50
51
# File 'lib/constant_contact_client/models/profile_dto.rb', line 49

def settings
  @settings
end

#urlObject

URL to the profile on the social network.



52
53
54
# File 'lib/constant_contact_client/models/profile_dto.rb', line 52

def url
  @url
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/constant_contact_client/models/profile_dto.rb', line 261

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = ConstantContactClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/constant_contact_client/models/profile_dto.rb', line 73

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/constant_contact_client/models/profile_dto.rb', line 55

def self.attribute_map
  {
    :'accessible' => :'accessible',
    :'account_info' => :'account_info',
    :'connected' => :'connected',
    :'handle' => :'handle',
    :'image_url' => :'image_url',
    :'name' => :'name',
    :'network' => :'network',
    :'network_profile_id' => :'network_profile_id',
    :'network_user_id' => :'network_user_id',
    :'profile_id' => :'profile_id',
    :'settings' => :'settings',
    :'url' => :'url'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/constant_contact_client/models/profile_dto.rb', line 237

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/constant_contact_client/models/profile_dto.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/constant_contact_client/models/profile_dto.rb', line 78

def self.openapi_types
  {
    :'accessible' => :'Boolean',
    :'account_info' => :'GetSocialProfiles200ResponseInnerAccountInfo',
    :'connected' => :'Boolean',
    :'handle' => :'String',
    :'image_url' => :'String',
    :'name' => :'String',
    :'network' => :'String',
    :'network_profile_id' => :'String',
    :'network_user_id' => :'String',
    :'profile_id' => :'String',
    :'settings' => :'Hash<String, Object>',
    :'url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/constant_contact_client/models/profile_dto.rb', line 205

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      accessible == o.accessible &&
       == o. &&
      connected == o.connected &&
      handle == o.handle &&
      image_url == o.image_url &&
      name == o.name &&
      network == o.network &&
      network_profile_id == o.network_profile_id &&
      network_user_id == o.network_user_id &&
      profile_id == o.profile_id &&
      settings == o.settings &&
      url == o.url
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/constant_contact_client/models/profile_dto.rb', line 332

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


224
225
226
# File 'lib/constant_contact_client/models/profile_dto.rb', line 224

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



230
231
232
# File 'lib/constant_contact_client/models/profile_dto.rb', line 230

def hash
  [accessible, , connected, handle, image_url, name, network, network_profile_id, network_user_id, profile_id, settings, url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/constant_contact_client/models/profile_dto.rb', line 175

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @connected.nil?
    invalid_properties.push('invalid value for "connected", connected cannot be nil.')
  end

  if @network.nil?
    invalid_properties.push('invalid value for "network", network cannot be nil.')
  end

  if @profile_id.nil?
    invalid_properties.push('invalid value for "profile_id", profile_id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



308
309
310
# File 'lib/constant_contact_client/models/profile_dto.rb', line 308

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/constant_contact_client/models/profile_dto.rb', line 314

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



302
303
304
# File 'lib/constant_contact_client/models/profile_dto.rb', line 302

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



195
196
197
198
199
200
201
# File 'lib/constant_contact_client/models/profile_dto.rb', line 195

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @connected.nil?
  return false if @network.nil?
  return false if @profile_id.nil?
  true
end