Class: ConstantContactClient::TrackDto1

Inherits:
Object
  • Object
show all
Defined in:
lib/constant_contact_client/models/track_dto1.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TrackDto1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/constant_contact_client/models/track_dto1.rb', line 122

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ConstantContactClient::TrackDto1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ConstantContactClient::TrackDto1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'campaign_activity_id')
    self.campaign_activity_id = attributes[:'campaign_activity_id']
  else
    self.campaign_activity_id = nil
  end

  if attributes.key?(:'conf_email_campaign_activity_id')
    self.conf_email_campaign_activity_id = attributes[:'conf_email_campaign_activity_id']
  end

  if attributes.key?(:'create_time')
    self.create_time = attributes[:'create_time']
  end

  if attributes.key?(:'items_header')
    self.items_header = attributes[:'items_header']
  end

  if attributes.key?(:'last_update_time')
    self.last_update_time = attributes[:'last_update_time']
  end

  if attributes.key?(:'media_assets')
    if (value = attributes[:'media_assets']).is_a?(Array)
      self.media_assets = value
    end
  end

  if attributes.key?(:'overall_ticket_capacity')
    self.overall_ticket_capacity = attributes[:'overall_ticket_capacity']
  end

  if attributes.key?(:'platform_fee_scope_type')
    self.platform_fee_scope_type = attributes[:'platform_fee_scope_type']
  end

  if attributes.key?(:'promo_codes')
    if (value = attributes[:'promo_codes']).is_a?(Array)
      self.promo_codes = value
    end
  end

  if attributes.key?(:'reg_manually_closed_flag')
    self.reg_manually_closed_flag = attributes[:'reg_manually_closed_flag']
  end

  if attributes.key?(:'registration_end_time')
    self.registration_end_time = attributes[:'registration_end_time']
  end

  if attributes.key?(:'registration_type')
    self.registration_type = attributes[:'registration_type']
  end

  if attributes.key?(:'restrict_to_single_ticket_flag')
    self.restrict_to_single_ticket_flag = attributes[:'restrict_to_single_ticket_flag']
  end

  if attributes.key?(:'tickets_header')
    self.tickets_header = attributes[:'tickets_header']
  end

  if attributes.key?(:'track_id')
    self.track_id = attributes[:'track_id']
  end

  if attributes.key?(:'items')
    if (value = attributes[:'items']).is_a?(Array)
      self.items = value
    end
  end
end

Instance Attribute Details

#campaign_activity_idObject

The campaign activity ID associated with the registration form.



19
20
21
# File 'lib/constant_contact_client/models/track_dto1.rb', line 19

def campaign_activity_id
  @campaign_activity_id
end

#conf_email_campaign_activity_idObject

The confirmation email campaign activity ID.



22
23
24
# File 'lib/constant_contact_client/models/track_dto1.rb', line 22

def conf_email_campaign_activity_id
  @conf_email_campaign_activity_id
end

#create_timeObject

The event's create time.



25
26
27
# File 'lib/constant_contact_client/models/track_dto1.rb', line 25

def create_time
  @create_time
end

#itemsObject

Returns the value of attribute items.



63
64
65
# File 'lib/constant_contact_client/models/track_dto1.rb', line 63

def items
  @items
end

#items_headerObject

items header



28
29
30
# File 'lib/constant_contact_client/models/track_dto1.rb', line 28

def items_header
  @items_header
end

#last_update_timeObject

The event's last modification time.



31
32
33
# File 'lib/constant_contact_client/models/track_dto1.rb', line 31

def last_update_time
  @last_update_time
end

#media_assetsObject

The list of media assets configured for the event.



34
35
36
# File 'lib/constant_contact_client/models/track_dto1.rb', line 34

def media_assets
  @media_assets
end

#overall_ticket_capacityObject

The total overall ticket capacity.



37
38
39
# File 'lib/constant_contact_client/models/track_dto1.rb', line 37

def overall_ticket_capacity
  @overall_ticket_capacity
end

#platform_fee_scope_typeObject

Specifies if the platform fee is passed to registrant or absorbed by the event host.



40
41
42
# File 'lib/constant_contact_client/models/track_dto1.rb', line 40

def platform_fee_scope_type
  @platform_fee_scope_type
end

#promo_codesObject

The list of promo_codes configured for the event.



43
44
45
# File 'lib/constant_contact_client/models/track_dto1.rb', line 43

def promo_codes
  @promo_codes
end

#reg_manually_closed_flagObject

Closes registration to prevent further registrations.



46
47
48
# File 'lib/constant_contact_client/models/track_dto1.rb', line 46

def reg_manually_closed_flag
  @reg_manually_closed_flag
end

#registration_end_timeObject

The date and time when registration should end. ISO format.



49
50
51
# File 'lib/constant_contact_client/models/track_dto1.rb', line 49

def registration_end_time
  @registration_end_time
end

#registration_typeObject

The registration type for the event.



52
53
54
# File 'lib/constant_contact_client/models/track_dto1.rb', line 52

def registration_type
  @registration_type
end

#restrict_to_single_ticket_flagObject

Restricts selection to a single ticket.



55
56
57
# File 'lib/constant_contact_client/models/track_dto1.rb', line 55

def restrict_to_single_ticket_flag
  @restrict_to_single_ticket_flag
end

#tickets_headerObject

The header to use for tickets.



58
59
60
# File 'lib/constant_contact_client/models/track_dto1.rb', line 58

def tickets_header
  @tickets_header
end

#track_idObject

The ticket track id.



61
62
63
# File 'lib/constant_contact_client/models/track_dto1.rb', line 61

def track_id
  @track_id
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/constant_contact_client/models/track_dto1.rb', line 290

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = ConstantContactClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



88
89
90
# File 'lib/constant_contact_client/models/track_dto1.rb', line 88

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/constant_contact_client/models/track_dto1.rb', line 66

def self.attribute_map
  {
    :'campaign_activity_id' => :'campaign_activity_id',
    :'conf_email_campaign_activity_id' => :'conf_email_campaign_activity_id',
    :'create_time' => :'create_time',
    :'items_header' => :'items_header',
    :'last_update_time' => :'last_update_time',
    :'media_assets' => :'media_assets',
    :'overall_ticket_capacity' => :'overall_ticket_capacity',
    :'platform_fee_scope_type' => :'platform_fee_scope_type',
    :'promo_codes' => :'promo_codes',
    :'reg_manually_closed_flag' => :'reg_manually_closed_flag',
    :'registration_end_time' => :'registration_end_time',
    :'registration_type' => :'registration_type',
    :'restrict_to_single_ticket_flag' => :'restrict_to_single_ticket_flag',
    :'tickets_header' => :'tickets_header',
    :'track_id' => :'track_id',
    :'items' => :'items'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/constant_contact_client/models/track_dto1.rb', line 266

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



115
116
117
118
# File 'lib/constant_contact_client/models/track_dto1.rb', line 115

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/constant_contact_client/models/track_dto1.rb', line 93

def self.openapi_types
  {
    :'campaign_activity_id' => :'String',
    :'conf_email_campaign_activity_id' => :'String',
    :'create_time' => :'String',
    :'items_header' => :'String',
    :'last_update_time' => :'String',
    :'media_assets' => :'Array<EventMediaAssetDto1>',
    :'overall_ticket_capacity' => :'Integer',
    :'platform_fee_scope_type' => :'String',
    :'promo_codes' => :'Array<PromoCodeDto1>',
    :'reg_manually_closed_flag' => :'Boolean',
    :'registration_end_time' => :'String',
    :'registration_type' => :'String',
    :'restrict_to_single_ticket_flag' => :'Boolean',
    :'tickets_header' => :'String',
    :'track_id' => :'String',
    :'items' => :'Array<ItemDto1>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/constant_contact_client/models/track_dto1.rb', line 230

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      campaign_activity_id == o.campaign_activity_id &&
      conf_email_campaign_activity_id == o.conf_email_campaign_activity_id &&
      create_time == o.create_time &&
      items_header == o.items_header &&
      last_update_time == o.last_update_time &&
      media_assets == o.media_assets &&
      overall_ticket_capacity == o.overall_ticket_capacity &&
      platform_fee_scope_type == o.platform_fee_scope_type &&
      promo_codes == o.promo_codes &&
      reg_manually_closed_flag == o.reg_manually_closed_flag &&
      registration_end_time == o.registration_end_time &&
      registration_type == o.registration_type &&
      restrict_to_single_ticket_flag == o.restrict_to_single_ticket_flag &&
      tickets_header == o.tickets_header &&
      track_id == o.track_id &&
      items == o.items
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/constant_contact_client/models/track_dto1.rb', line 361

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


253
254
255
# File 'lib/constant_contact_client/models/track_dto1.rb', line 253

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



259
260
261
# File 'lib/constant_contact_client/models/track_dto1.rb', line 259

def hash
  [campaign_activity_id, conf_email_campaign_activity_id, create_time, items_header, last_update_time, media_assets, overall_ticket_capacity, platform_fee_scope_type, promo_codes, reg_manually_closed_flag, registration_end_time, registration_type, restrict_to_single_ticket_flag, tickets_header, track_id, items].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



210
211
212
213
214
215
216
217
218
# File 'lib/constant_contact_client/models/track_dto1.rb', line 210

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @campaign_activity_id.nil?
    invalid_properties.push('invalid value for "campaign_activity_id", campaign_activity_id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



337
338
339
# File 'lib/constant_contact_client/models/track_dto1.rb', line 337

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/constant_contact_client/models/track_dto1.rb', line 343

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



331
332
333
# File 'lib/constant_contact_client/models/track_dto1.rb', line 331

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



222
223
224
225
226
# File 'lib/constant_contact_client/models/track_dto1.rb', line 222

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @campaign_activity_id.nil?
  true
end