Class: ConstantContactClient::SMSReportingApi
- Inherits:
-
Object
- Object
- ConstantContactClient::SMSReportingApi
- Defined in:
- lib/constant_contact_client/api/sms_reporting_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_all_bulk_sms_campaign_summaries(start_at, opts = {}) ⇒ GetAllBulkSmsCampaignSummaries200Response
GET an SMS Campaigns Summary Report Use this method to get SMS campaign summary details, including the total number of times that each contact uniquely interacted with each tracked campaign activity and aggregate tracking statistics.
-
#get_all_bulk_sms_campaign_summaries_with_http_info(start_at, opts = {}) ⇒ Array<(GetAllBulkSmsCampaignSummaries200Response, Integer, Hash)>
GET an SMS Campaigns Summary Report Use this method to get SMS campaign summary details, including the total number of times that each contact uniquely interacted with each tracked campaign activity and aggregate tracking statistics.
-
#initialize(api_client = ApiClient.default) ⇒ SMSReportingApi
constructor
A new instance of SMSReportingApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ SMSReportingApi
Returns a new instance of SMSReportingApi.
19 20 21 |
# File 'lib/constant_contact_client/api/sms_reporting_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/constant_contact_client/api/sms_reporting_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_all_bulk_sms_campaign_summaries(start_at, opts = {}) ⇒ GetAllBulkSmsCampaignSummaries200Response
GET an SMS Campaigns Summary Report
Use this method to get SMS campaign summary details, including the total number of times that each contact uniquely interacted with each tracked campaign activity and aggregate tracking statistics. Results are sorted in descending order by the date the SMS was last sent (last_sent_date). The start_at date is required. Use both the start_at and end_at date query parameters to return only SMS campaign summary details that occurred within a specified date range. Use the limit query parameter to limit the number of results returned per page.
29 30 31 32 |
# File 'lib/constant_contact_client/api/sms_reporting_api.rb', line 29 def get_all_bulk_sms_campaign_summaries(start_at, opts = {}) data, _status_code, _headers = get_all_bulk_sms_campaign_summaries_with_http_info(start_at, opts) data end |
#get_all_bulk_sms_campaign_summaries_with_http_info(start_at, opts = {}) ⇒ Array<(GetAllBulkSmsCampaignSummaries200Response, Integer, Hash)>
GET an SMS Campaigns Summary Report Use this method to get SMS campaign summary details, including the total number of times that each contact uniquely interacted with each tracked campaign activity and aggregate tracking statistics. Results are sorted in descending order by the date the SMS was last sent (`last_sent_date`). The `start_at` date is required. Use both the `start_at` and `end_at` date query parameters to return only SMS campaign summary details that occurred within a specified date range. Use the `limit` query parameter to limit the number of results returned per page.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/constant_contact_client/api/sms_reporting_api.rb', line 41 def get_all_bulk_sms_campaign_summaries_with_http_info(start_at, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SMSReportingApi.get_all_bulk_sms_campaign_summaries ...' end # verify the required parameter 'start_at' is set if @api_client.config.client_side_validation && start_at.nil? fail ArgumentError, "Missing the required parameter 'start_at' when calling SMSReportingApi.get_all_bulk_sms_campaign_summaries" end # resource path local_var_path = '/reports/summary_reports/sms_campaign_summaries' # query parameters query_params = opts[:query_params] || {} query_params[:'start_at'] = start_at query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'end_at'] = opts[:'end_at'] if !opts[:'end_at'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetAllBulkSmsCampaignSummaries200Response' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2_access_code', 'oauth2_implicit'] = opts.merge( :operation => :"SMSReportingApi.get_all_bulk_sms_campaign_summaries", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SMSReportingApi#get_all_bulk_sms_campaign_summaries\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |