Class: ConstantContactClient::SegmentsApi
- Inherits:
-
Object
- Object
- ConstantContactClient::SegmentsApi
- Defined in:
- lib/constant_contact_client/api/segments_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_segment(create_segment_request, opts = {}) ⇒ CreateSegment201Response
POST (create) a Segment Use this method to create a new segment.
-
#create_segment_with_http_info(create_segment_request, opts = {}) ⇒ Array<(CreateSegment201Response, Integer, Hash)>
POST (create) a Segment Use this method to create a new segment.
-
#delete_segment(segment_id, opts = {}) ⇒ nil
DELETE a Segment Use this method to delete a segment from your account.
-
#delete_segment_with_http_info(segment_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
DELETE a Segment Use this method to delete a segment from your account.
-
#get_all_segments(opts = {}) ⇒ GetAllSegments200Response
GET all Segments Use this method to get a list of all segments associated with the account.
-
#get_all_segments_with_http_info(opts = {}) ⇒ Array<(GetAllSegments200Response, Integer, Hash)>
GET all Segments Use this method to get a list of all segments associated with the account.
-
#get_segment_by_id(segment_id, opts = {}) ⇒ CreateSegment201Response
GET a Segment's Details Use this method to get details about a segment, including the segment criteria.
-
#get_segment_by_id_with_http_info(segment_id, opts = {}) ⇒ Array<(CreateSegment201Response, Integer, Hash)>
GET a Segment's Details Use this method to get details about a segment, including the segment criteria.
-
#initialize(api_client = ApiClient.default) ⇒ SegmentsApi
constructor
A new instance of SegmentsApi.
-
#update_segment(segment_id, create_segment_request, opts = {}) ⇒ CreateSegment201Response
PUT (update) a Segment Use this method to update an existing segment's name (
name) and/or contact selection criteria (segment_criteria). -
#update_segment_name(segment_id, update_segment_name_request, opts = {}) ⇒ CreateSegment201Response
PATCH (rename) a Segment Use this method to update an existing segment
namewith a new unique name in the request body. -
#update_segment_name_with_http_info(segment_id, update_segment_name_request, opts = {}) ⇒ Array<(CreateSegment201Response, Integer, Hash)>
PATCH (rename) a Segment Use this method to update an existing segment `name` with a new unique name in the request body.
-
#update_segment_with_http_info(segment_id, create_segment_request, opts = {}) ⇒ Array<(CreateSegment201Response, Integer, Hash)>
PUT (update) a Segment Use this method to update an existing segment's name (`name`) and/or contact selection criteria (`segment_criteria`).
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ SegmentsApi
Returns a new instance of SegmentsApi.
19 20 21 |
# File 'lib/constant_contact_client/api/segments_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/constant_contact_client/api/segments_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_segment(create_segment_request, opts = {}) ⇒ CreateSegment201Response
POST (create) a Segment
Use this method to create a new segment. You create segments to target a subset of your contacts that meet your specific criteria for a marketing campaign. The segment name must be unique. The segment_criteria requires single-string escaped JSON. Constant Contact uses the contact data that you specify in the segment_criteria to evaluate and identify the contacts you want to target. Contact data can be grouped from different data sources, including: - tracking: Supports or and and groups. - contact: Supports or and and groups. - list_membership: Supports or groups. - tags: Supports or groups. If you do not specify list_membership as criteria, Constant Contact evaluates all contacts in your account. To avoid returning a 400 error response, when specifying the segment_criteria do not request more than 500 email campaigns or a date range greater than 1825 days (5 years) be evaluated. For more use case information, see the Segments Overview in the API guide.
27 28 29 30 |
# File 'lib/constant_contact_client/api/segments_api.rb', line 27 def create_segment(create_segment_request, opts = {}) data, _status_code, _headers = create_segment_with_http_info(create_segment_request, opts) data end |
#create_segment_with_http_info(create_segment_request, opts = {}) ⇒ Array<(CreateSegment201Response, Integer, Hash)>
POST (create) a Segment Use this method to create a new segment. You create segments to target a subset of your contacts that meet your specific criteria for a marketing campaign. The segment `name` must be unique. The `segment_criteria` requires single-string escaped JSON. Constant Contact uses the contact data that you specify in the `segment_criteria` to evaluate and identify the contacts you want to target. Contact data can be grouped from different data sources, including: - `tracking`: Supports or and and groups. - `contact`: Supports or and and groups. - `list_membership`: Supports or groups. - `tags`: Supports or groups. If you do not specify `list_membership` as criteria, Constant Contact evaluates all contacts in your account. To avoid returning a 400 error response, when specifying the `segment_criteria` do not request more than 500 email campaigns or a date range greater than 1825 days (5 years) be evaluated. For more use case information, see the Segments Overview in the API guide.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/constant_contact_client/api/segments_api.rb', line 37 def create_segment_with_http_info(create_segment_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SegmentsApi.create_segment ...' end # verify the required parameter 'create_segment_request' is set if @api_client.config.client_side_validation && create_segment_request.nil? fail ArgumentError, "Missing the required parameter 'create_segment_request' when calling SegmentsApi.create_segment" end # resource path local_var_path = '/segments' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_segment_request) # return_type return_type = opts[:debug_return_type] || 'CreateSegment201Response' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2_access_code', 'oauth2_implicit'] = opts.merge( :operation => :"SegmentsApi.create_segment", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SegmentsApi#create_segment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_segment(segment_id, opts = {}) ⇒ nil
DELETE a Segment
Use this method to delete a segment from your account. Before deleting a segment, verify that the segment is not associated with a scheduled campaign. Deleted segments do not display in the results when using the GET /segments endpoint. If you know the segment_id, you can use the GET /segments/{segment_id} endpoint to view the deleted segment's details. A segment's details are preserved for external reference purposes, such as displaying the segment name in a campaign's history. For more use case information, see Delete a Segment in the API guide.
95 96 97 98 |
# File 'lib/constant_contact_client/api/segments_api.rb', line 95 def delete_segment(segment_id, opts = {}) delete_segment_with_http_info(segment_id, opts) nil end |
#delete_segment_with_http_info(segment_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
DELETE a Segment Use this method to delete a segment from your account. Before deleting a segment, verify that the segment is not associated with a scheduled campaign. Deleted segments do not display in the results when using the `GET /segments` endpoint. If you know the `segment_id`, you can use the `GET /segments/segment_id` endpoint to view the deleted segment's details. A segment's details are preserved for external reference purposes, such as displaying the segment name in a campaign's history. For more use case information, see Delete a Segment in the API guide.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/constant_contact_client/api/segments_api.rb', line 105 def delete_segment_with_http_info(segment_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SegmentsApi.delete_segment ...' end # verify the required parameter 'segment_id' is set if @api_client.config.client_side_validation && segment_id.nil? fail ArgumentError, "Missing the required parameter 'segment_id' when calling SegmentsApi.delete_segment" end # resource path local_var_path = '/segments/{segment_id}'.sub('{' + 'segment_id' + '}', CGI.escape(segment_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['oauth2_access_code', 'oauth2_implicit'] = opts.merge( :operation => :"SegmentsApi.delete_segment", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SegmentsApi#delete_segment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_all_segments(opts = {}) ⇒ GetAllSegments200Response
GET all Segments Use this method to get a list of all segments associated with the account. You can sort segment results and limit the number of segments that display per page. Deleted segments are excluded from the results. For more use case information, see Get All Segments in the API guide.
157 158 159 160 |
# File 'lib/constant_contact_client/api/segments_api.rb', line 157 def get_all_segments(opts = {}) data, _status_code, _headers = get_all_segments_with_http_info(opts) data end |
#get_all_segments_with_http_info(opts = {}) ⇒ Array<(GetAllSegments200Response, Integer, Hash)>
GET all Segments Use this method to get a list of all segments associated with the account. You can sort segment results and limit the number of segments that display per page. Deleted segments are excluded from the results. For more use case information, see Get All Segments in the API guide.
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/constant_contact_client/api/segments_api.rb', line 168 def get_all_segments_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SegmentsApi.get_all_segments ...' end # resource path local_var_path = '/segments' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort_by'] = opts[:'sort_by'] if !opts[:'sort_by'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetAllSegments200Response' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2_access_code', 'oauth2_implicit'] = opts.merge( :operation => :"SegmentsApi.get_all_segments", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SegmentsApi#get_all_segments\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_segment_by_id(segment_id, opts = {}) ⇒ CreateSegment201Response
GET a Segment's Details
Use this method to get details about a segment, including the segment criteria. If you know the segment_id You can also use this method to get details about a deleted segment. For more use case information, see Get a Segment's Details in the API guide.
219 220 221 222 |
# File 'lib/constant_contact_client/api/segments_api.rb', line 219 def get_segment_by_id(segment_id, opts = {}) data, _status_code, _headers = get_segment_by_id_with_http_info(segment_id, opts) data end |
#get_segment_by_id_with_http_info(segment_id, opts = {}) ⇒ Array<(CreateSegment201Response, Integer, Hash)>
GET a Segment's Details Use this method to get details about a segment, including the segment criteria. If you know the `segment_id` You can also use this method to get details about a deleted segment. For more use case information, see Get a Segment's Details in the API guide.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/constant_contact_client/api/segments_api.rb', line 229 def get_segment_by_id_with_http_info(segment_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SegmentsApi.get_segment_by_id ...' end # verify the required parameter 'segment_id' is set if @api_client.config.client_side_validation && segment_id.nil? fail ArgumentError, "Missing the required parameter 'segment_id' when calling SegmentsApi.get_segment_by_id" end # resource path local_var_path = '/segments/{segment_id}'.sub('{' + 'segment_id' + '}', CGI.escape(segment_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CreateSegment201Response' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2_access_code', 'oauth2_implicit'] = opts.merge( :operation => :"SegmentsApi.get_segment_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SegmentsApi#get_segment_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_segment(segment_id, create_segment_request, opts = {}) ⇒ CreateSegment201Response
PUT (update) a Segment
Use this method to update an existing segment's name (name) and/or contact selection criteria (segment_criteria). You must specify both the name and the segment_criteria in the request body, even if you don't plan to update both. The segment's name must be unique and the JSON must be valid (requires single-string escaped JSON). To avoid returning a 400 error response, when specifying the segment_criteria do not request more than 500 email campaigns or a date range greater than 1825 days (5 years) be evaluated. For more use case information, see Update Segment Details in the API guide.
283 284 285 286 |
# File 'lib/constant_contact_client/api/segments_api.rb', line 283 def update_segment(segment_id, create_segment_request, opts = {}) data, _status_code, _headers = update_segment_with_http_info(segment_id, create_segment_request, opts) data end |
#update_segment_name(segment_id, update_segment_name_request, opts = {}) ⇒ CreateSegment201Response
PATCH (rename) a Segment
Use this method to update an existing segment name with a new unique name in the request body. For more use case information, see Rename a Segment in the API guide.
357 358 359 360 |
# File 'lib/constant_contact_client/api/segments_api.rb', line 357 def update_segment_name(segment_id, update_segment_name_request, opts = {}) data, _status_code, _headers = update_segment_name_with_http_info(segment_id, update_segment_name_request, opts) data end |
#update_segment_name_with_http_info(segment_id, update_segment_name_request, opts = {}) ⇒ Array<(CreateSegment201Response, Integer, Hash)>
PATCH (rename) a Segment Use this method to update an existing segment `name` with a new unique name in the request body. For more use case information, see Rename a Segment in the API guide.
368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/constant_contact_client/api/segments_api.rb', line 368 def update_segment_name_with_http_info(segment_id, update_segment_name_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SegmentsApi.update_segment_name ...' end # verify the required parameter 'segment_id' is set if @api_client.config.client_side_validation && segment_id.nil? fail ArgumentError, "Missing the required parameter 'segment_id' when calling SegmentsApi.update_segment_name" end # verify the required parameter 'update_segment_name_request' is set if @api_client.config.client_side_validation && update_segment_name_request.nil? fail ArgumentError, "Missing the required parameter 'update_segment_name_request' when calling SegmentsApi.update_segment_name" end # resource path local_var_path = '/segments/{segment_id}/name'.sub('{' + 'segment_id' + '}', CGI.escape(segment_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_segment_name_request) # return_type return_type = opts[:debug_return_type] || 'CreateSegment201Response' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2_access_code', 'oauth2_implicit'] = opts.merge( :operation => :"SegmentsApi.update_segment_name", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SegmentsApi#update_segment_name\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_segment_with_http_info(segment_id, create_segment_request, opts = {}) ⇒ Array<(CreateSegment201Response, Integer, Hash)>
PUT (update) a Segment Use this method to update an existing segment's name (`name`) and/or contact selection criteria (`segment_criteria`). You must specify both the `name` and the `segment_criteria` in the request body, even if you don't plan to update both. The segment's name must be unique and the JSON must be valid (requires single-string escaped JSON). To avoid returning a 400 error response, when specifying the `segment_criteria` do not request more than 500 email campaigns or a date range greater than 1825 days (5 years) be evaluated. For more use case information, see Update Segment Details in the API guide.
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/constant_contact_client/api/segments_api.rb', line 294 def update_segment_with_http_info(segment_id, create_segment_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SegmentsApi.update_segment ...' end # verify the required parameter 'segment_id' is set if @api_client.config.client_side_validation && segment_id.nil? fail ArgumentError, "Missing the required parameter 'segment_id' when calling SegmentsApi.update_segment" end # verify the required parameter 'create_segment_request' is set if @api_client.config.client_side_validation && create_segment_request.nil? fail ArgumentError, "Missing the required parameter 'create_segment_request' when calling SegmentsApi.update_segment" end # resource path local_var_path = '/segments/{segment_id}'.sub('{' + 'segment_id' + '}', CGI.escape(segment_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_segment_request) # return_type return_type = opts[:debug_return_type] || 'CreateSegment201Response' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2_access_code', 'oauth2_implicit'] = opts.merge( :operation => :"SegmentsApi.update_segment", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SegmentsApi#update_segment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |